==> flutter_googlefit-0.0.38.tar.gz: android/src/main/java/com/dh/fluttergooglefit/FlutterGooglefitPlugin.java <==
package com.dh.fluttergooglefit;

import android.app.Activity;
import android.content.Intent;
import android.content.pm.ActivityInfo;
import android.support.annotation.NonNull;
import android.util.Log;

import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;
import io.flutter.plugin.common.PluginRegistry;

import com.google.android.gms.auth.api.signin.GoogleSignIn;
import com.google.android.gms.fitness.Fitness;
import com.google.android.gms.fitness.FitnessOptions;
import com.google.android.gms.fitness.data.DataPoint;
import com.google.android.gms.fitness.data.DataSet;
import com.google.android.gms.fitness.data.DataType;
import com.google.android.gms.fitness.data.Field;
import com.google.android.gms.fitness.request.DataReadRequest;
import com.google.android.gms.fitness.result.DataReadResponse;
import com.google.android.gms.tasks.OnCanceledListener;
import com.google.android.gms.tasks.OnCompleteListener;
import com.google.android.gms.tasks.OnFailureListener;
import com.google.android.gms.tasks.OnSuccessListener;
import com.google.android.gms.tasks.Task;

import java.text.DateFormat;
import java.text.SimpleDateFormat;
import java.text.ParseException;
import java.util.Calendar;
import java.util.Date;
import java.util.HashMap;
import java.util.concurrent.TimeUnit;

public class FlutterGooglefitPlugin implements MethodCallHandler, PluginRegistry.ActivityResultListener {
  private Registrar registrar;
  private Result mResult;

  private static final int GOOGLE_FIT_PERMISSIONS_REQUEST_CODE = 375678;

  // 필요한 권한들 정의
  FitnessOptions fitnessOptions =
          FitnessOptions.builder()
                  .addDataType(DataType.TYPE_STEP_COUNT_CUMULATIVE, FitnessOptions.ACCESS_READ)
                  .addDataType(DataType.TYPE_STEP_COUNT_DELTA, FitnessOptions.ACCESS_READ)
                  .build();

  public static void registerWith(Registrar registrar) {
    final MethodChannel channel = new MethodChannel(registrar.messenger(), "com.dh/flutter_googlefit");
    FlutterGooglefitPlugin googlefitPlugin = new FlutterGooglefitPlugin(registrar);
    channel.setMethodCallHandler(googlefitPlugin);
    registrar.addActivityResultListener(googlefitPlugin);
  }

  private FlutterGooglefitPlugin(Registrar registrar) {
    this.registrar = registrar;
  }

  @Override
  public void onMethodCall(MethodCall call, Result result) {
    this.mResult = result;
    switch (call.method) {
      case "reqCheckPermissionGoogleFit":
        if( CheckPermissionFit() == true )
          mResult.success(true);
        else
          mResult.success(false);
      break;
      case "reqPermissionGoogleFit":
        ReqPermissionGoogleFit();
        break;
      case "reqTotalStepData":
        readTotalStepData((String)call.argument("targetStartDate"), (String)call.argument("targetEndDate"));
        break;
      default:
        result.notImplemented();
        break;
    }
  }

  @Override
  public boolean onActivityResult(int requestCode, int reslutCode, Intent data) {

    if( requestCode == GOOGLE_FIT_PERMISSIONS_REQUEST_CODE )
    {
      if( reslutCode == Activity.RESULT_OK)
      {
        // 성공. 리스너 등록.
        AddListenerFIt();
      }
      else
      {
        // 실패.
        mResult.success(null  );
      }
    }

    return false;
  }


  // 피트 권한 확인.
  public boolean CheckPermissionFit()
  {
    return GoogleSignIn.hasPermissions(GoogleSignIn.getLastSignedInAccount(registrar.activity()), fitnessOptions);
  }

  // 피트 권한 요청.
  public void ReqPermissionGoogleFit()
  {
    if(!CheckPermissionFit()) {
      GoogleSignIn.requestPermissions(registrar.activity(), GOOGLE_FIT_PERMISSIONS_REQUEST_CODE, GoogleSignIn.getLastSignedInAccount(registrar.activity()), fitnessOptions);
    }
    else
    {
      mResult.success(null  );
    }
  }

  public void AddListenerFIt()
  {
    Fitness.getRecordingClient(registrar.activity(),
            GoogleSignIn.getLastSignedInAccount(registrar.activity()))
            .subscribe(DataType.TYPE_STEP_COUNT_CUMULATIVE)
            .addOnCanceledListener(new OnCanceledListener() {
              @Override
              public void onCanceled() {
                mResult.error("ReqPermissionGoogleFit", "addOnCanceledListener", null);
              }
            })
            .addOnFailureListener(new OnFailureListener() {
              @Override
              public void onFailure(@NonNull Exception e) {
                mResult.error("ReqPermissionGoogleFit", "addOnFailureListener", null);
              }
            })
            .addOnCompleteListener(new OnCompleteListener<Void>() {
              @Override
              public void onComplete(@NonNull Task<Void> task) {
                if (task.isSuccessful()) {
                  //readTotalStepData();
                } else {

                }

                mResult.success(null);
              }
            });
  }

  public void readTotalStepData(String targetStartDate, String targetEndDate) {

    if( CheckPermissionFit() == false )
    {
      mResult.error("readTotalStepData", "NeedPermission", 0 );
      return;
    }

    SimpleDateFormat formatter = new SimpleDateFormat("yyyy-MM-dd");
    Date date;
    try{
      date =formatter.parse(targetStartDate);
    }catch (ParseException e )
    {
      mResult.error("readTotalStepData", "formatter.parse", 0 );
      return;
    }

    SimpleDateFormat formatter2 = new SimpleDateFormat("yyyy-MM-dd");
    Date date2;
    try{
      date2 =formatter2.parse(targetEndDate);
    }catch (ParseException e )
    {
      mResult.error("readTotalStepData", "formatter2.parse", 0 );
      return;
    }

    final Calendar cal = Calendar.getInstance();
    cal.setTime(date);
    // 시작 시간
    cal.set(cal.get(Calendar.YEAR), cal.get(Calendar.MONTH),
            cal.get(Calendar.DAY_OF_MONTH), 0, 0, 0);
    long startTime = cal.getTimeInMillis();

    // 종료 시간
    cal.setTime(date2);
    cal.set(cal.get(Calendar.YEAR), cal.get(Calendar.MONTH),
            cal.get(Calendar.DAY_OF_MONTH), 23, 59, 55);
    long endTime = cal.getTimeInMillis();

    Fitness.getHistoryClient(registrar.activity(),
            GoogleSignIn.getLastSignedInAccount(registrar.activity()))
            .readData(new DataReadRequest.Builder()
                    .read(DataType.AGGREGATE_STEP_COUNT_DELTA )
                    .bucketByTime(1, TimeUnit.DAYS)// Raw 걸음 수
                    .setTimeRange(startTime, endTime, TimeUnit.DAYS)
                    .build())
            .addOnFailureListener(new OnFailureListener() {
              @Override
              public void onFailure(@NonNull Exception e) {
                mResult.error("readTotalStepData", "FailureListener", 0);
              }
            })
            .addOnCanceledListener(new OnCanceledListener() {
              @Override
              public void onCanceled() {
                mResult.error("readTotalStepData", "CanceledListener", 0);
              }
            })
            .addOnSuccessListener(new OnSuccessListener<DataReadResponse>() {
              @Override
              public void onSuccess(DataReadResponse response) {
                DataSet dataSet = response.getDataSet(DataType.AGGREGATE_STEP_COUNT_DELTA );
                int temp = 0;
                for (DataPoint dp : dataSet.getDataPoints()) {
                  for (Field field : dp.getDataType().getFields()) {
                    temp = temp + Integer.parseInt( dp.getValue(field).toString() );
                    Log.i("healthcoin", "\tField: " + field.getName() + " Value: " + dp.getValue(field));

                  }
                }
                final Integer count = temp;
                mResult.success( count );
              }
            });
  }
}

==> flutter_googlefit-0.0.41.tar.gz: android/src/main/java/com/dh/fluttergooglefit/FlutterGooglefitPlugin.java <==
package com.dh.fluttergooglefit;

import android.app.Activity;
import android.content.Intent;
import android.content.pm.ActivityInfo;
import android.support.annotation.NonNull;
import android.util.Log;

import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;
import io.flutter.plugin.common.PluginRegistry;

import com.google.android.gms.auth.api.signin.GoogleSignIn;
import com.google.android.gms.fitness.Fitness;
import com.google.android.gms.fitness.FitnessOptions;
import com.google.android.gms.fitness.data.DataPoint;
import com.google.android.gms.fitness.data.DataSet;
import com.google.android.gms.fitness.data.DataType;
import com.google.android.gms.fitness.data.Field;
import com.google.android.gms.fitness.request.DataReadRequest;
import com.google.android.gms.fitness.result.DataReadResponse;
import com.google.android.gms.tasks.OnCanceledListener;
import com.google.android.gms.tasks.OnCompleteListener;
import com.google.android.gms.tasks.OnFailureListener;
import com.google.android.gms.tasks.OnSuccessListener;
import com.google.android.gms.tasks.Task;

import java.text.DateFormat;
import java.text.SimpleDateFormat;
import java.text.ParseException;
import java.util.Calendar;
import java.util.Date;
import java.util.HashMap;
import java.util.concurrent.TimeUnit;

public class FlutterGooglefitPlugin implements MethodCallHandler, PluginRegistry.ActivityResultListener {
  private Registrar registrar;
  private Result mResult;

  private static final int GOOGLE_FIT_PERMISSIONS_REQUEST_CODE = 375678;

  // 필요한 권한들 정의
  FitnessOptions fitnessOptions =
          FitnessOptions.builder()
                  .addDataType(DataType.TYPE_STEP_COUNT_CUMULATIVE, FitnessOptions.ACCESS_READ)
                  .addDataType(DataType.TYPE_STEP_COUNT_DELTA, FitnessOptions.ACCESS_READ)
                  .build();

  public static void registerWith(Registrar registrar) {
    final MethodChannel channel = new MethodChannel(registrar.messenger(), "com.dh/flutter_googlefit");
    FlutterGooglefitPlugin googlefitPlugin = new FlutterGooglefitPlugin(registrar);
    channel.setMethodCallHandler(googlefitPlugin);
    registrar.addActivityResultListener(googlefitPlugin);
  }

  private FlutterGooglefitPlugin(Registrar registrar) {
    this.registrar = registrar;
  }

  @Override
  public void onMethodCall(MethodCall call, Result result) {
    this.mResult = result;
    switch (call.method) {
      case "reqCheckPermissionGoogleFit":
        if( CheckPermissionFit() == true )
          mResult.success(true);
        else
          mResult.success(false);
      break;
      case "reqPermissionGoogleFit":
        ReqPermissionGoogleFit();
        break;
      case "reqTotalStepData":
        readTotalStepData((String)call.argument("targetStartDate"), (String)call.argument("targetEndDate"));
        break;
      default:
        result.notImplemented();
        break;
    }
  }

  @Override
  public boolean onActivityResult(int requestCode, int reslutCode, Intent data) {

    if( requestCode == GOOGLE_FIT_PERMISSIONS_REQUEST_CODE )
    {
      if( reslutCode == Activity.RESULT_OK)
      {
        // 성공. 리스너 등록.
        AddListenerFIt();
      }
      else
      {
        // 실패.
        mResult.success(null  );
      }
    }

    return false;
  }


  // 피트 권한 확인.
  public boolean CheckPermissionFit()
  {
    return GoogleSignIn.hasPermissions(GoogleSignIn.getLastSignedInAccount(registrar.activity()), fitnessOptions);
  }

  // 피트 권한 요청.
  public void ReqPermissionGoogleFit()
  {
    if(!CheckPermissionFit()) {
      GoogleSignIn.requestPermissions(registrar.activity(), GOOGLE_FIT_PERMISSIONS_REQUEST_CODE, GoogleSignIn.getLastSignedInAccount(registrar.activity()), fitnessOptions);
    }
    else
    {
      mResult.success(null  );
    }
  }

  public void AddListenerFIt()
  {
    Fitness.getRecordingClient(registrar.activity(),
            GoogleSignIn.getLastSignedInAccount(registrar.activity()))
            .subscribe(DataType.TYPE_STEP_COUNT_CUMULATIVE)
            .addOnCanceledListener(new OnCanceledListener() {
              @Override
              public void onCanceled() {
                mResult.error("ReqPermissionGoogleFit", "addOnCanceledListener", null);
              }
            })
            .addOnFailureListener(new OnFailureListener() {
              @Override
              public void onFailure(@NonNull Exception e) {
                mResult.error("ReqPermissionGoogleFit", "addOnFailureListener", null);
              }
            })
            .addOnCompleteListener(new OnCompleteListener<Void>() {
              @Override
              public void onComplete(@NonNull Task<Void> task) {
                if (task.isSuccessful()) {
                  //readTotalStepData();
                } else {

                }

                mResult.success(null);
              }
            });
  }

  public void readTotalStepData(String targetStartDate, String targetEndDate) {

    if( CheckPermissionFit() == false )
    {
      mResult.error("readTotalStepData", "NeedPermission", 0 );
      return;
    }

    SimpleDateFormat formatter = new SimpleDateFormat("yyyy-MM-dd");
    Date date;
    try{
      date =formatter.parse(targetStartDate);
    }catch (ParseException e )
    {
      mResult.error("readTotalStepData", "formatter.parse", 0 );
      return;
    }

    SimpleDateFormat formatter2 = new SimpleDateFormat("yyyy-MM-dd");
    Date date2;
    try{
      date2 =formatter2.parse(targetEndDate);
    }catch (ParseException e )
    {
      mResult.error("readTotalStepData", "formatter2.parse", 0 );
      return;
    }

    final Calendar cal = Calendar.getInstance();
    cal.setTime(date);
    // 시작 시간
    cal.set(cal.get(Calendar.YEAR), cal.get(Calendar.MONTH),
            cal.get(Calendar.DAY_OF_MONTH), 0, 0, 0);
    long startTime = cal.getTimeInMillis();

    // 종료 시간
    cal.setTime(date2);
    cal.set(cal.get(Calendar.YEAR), cal.get(Calendar.MONTH),
            cal.get(Calendar.DAY_OF_MONTH), 23, 59, 55);
    long endTime = cal.getTimeInMillis();

    Fitness.getHistoryClient(registrar.activity(),
            GoogleSignIn.getLastSignedInAccount(registrar.activity()))
            .readData(new DataReadRequest.Builder()
                    .read(DataType.AGGREGATE_STEP_COUNT_DELTA )
                    //.bucketByTime(1, TimeUnit.DAYS)// Raw 걸음 수
                    .setTimeRange(startTime, endTime, TimeUnit.DAYS)
                    .build())
            .addOnFailureListener(new OnFailureListener() {
              @Override
              public void onFailure(@NonNull Exception e) {
                mResult.error("readTotalStepData", "FailureListener", 0);
              }
            })
            .addOnCanceledListener(new OnCanceledListener() {
              @Override
              public void onCanceled() {
                mResult.error("readTotalStepData", "CanceledListener", 0);
              }
            })
            .addOnSuccessListener(new OnSuccessListener<DataReadResponse>() {
              @Override
              public void onSuccess(DataReadResponse response) {
                DataSet dataSet = response.getDataSet(DataType.AGGREGATE_STEP_COUNT_DELTA );
                int temp = 0;
                for (DataPoint dp : dataSet.getDataPoints()) {
                  for (Field field : dp.getDataType().getFields()) {
                    temp = temp + Integer.parseInt( dp.getValue(field).toString() );
                    Log.i("healthcoin", "\tField: " + field.getName() + " Value: " + dp.getValue(field));

                  }
                }
                final Integer count = temp;
                mResult.success( count );
              }
            });
  }
}
